@@ -85,7 +85,7 @@
 #define KCMUTILSQUICK_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCMUTILSQUICK_NO_DEPRECATED
-#  define KCMUTILSQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60c00
+#  define KCMUTILSQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT 0x61200
 #endif
 #ifdef KCMUTILSQUICK_NO_DEPRECATED_WARNINGS
 #  define KCMUTILSQUICK_DEPRECATED_WARNINGS_SINCE 0
@@ -95,7 +95,7 @@
 #  ifdef KCMUTILSQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCMUTILSQUICK_DEPRECATED_WARNINGS_SINCE KCMUTILSQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCMUTILSQUICK_DEPRECATED_WARNINGS_SINCE 0x60c00
+#    define KCMUTILSQUICK_DEPRECATED_WARNINGS_SINCE 0x61200
 #  endif
 #endif
 
